# MaLeMBa - Machine Learning Models Base

Python package for base manipulations with datasets and machine learning models wrapping

## Installation

To install the package from PyPI type:

```
pip install malemba
```

Or from the repo:

```
pip install git+https://github.com/loven-doo/MaLeMBa.git
```

For 'dev' branch version:

```
pip install git+https://github.com/loven-doo/MaLeMBa.git@dev
```

## Package reference

### ModelBase

### ds_tools

